@@ -27,6 +27,20 @@
 
 
 get_surrogates <- function(dat) {
+
+  # remove rows with completely missing data
+  missing <- apply(dat, 1, function(d) all(is.na(d)))
+  if (any(missing)) {
+    dat <- subset(dat, !missing)
+    message(paste("Warning:", sum(missing), "rows removed due to missing data"))
+  }
+
+  # mean imputation for missing data
+  if (any(is.na(dat))) {
+    dat <- t(apply(dat, 1, function(d) {
+      d[is.na(d)] <- mean(d[!is.na(d)])
+      d}))
+  }
   dev_scores <- scale(dat, scale = FALSE)
   svd_dev <- svd(dev_scores)
   pc1 <- svd_dev$u[, 1]
