@@ -2,10 +2,9 @@
 #'
 #' Create a matrix for numerical integration.
 #'
-#' @param distr A density function with two user-specified parameters.
-#' Defaults to the normal distribution, but any density function is permitted
-#' @param par1 First parameter passed to distr.
-#' @param par2 Second parameter passed to distr.
+#' @param distr A density function with two user-specified parameters. Defaults
+#' to the normal distribution (dnorm), but any density function is permitted.
+#' @param args Named list of arguments to distr.
 #' @param lb Lower bound of range over which to numerically integrate.
 #' @param ub Upper bound of range over which to numerically integrate.
 #' @param npts Number of integration points.
@@ -16,17 +15,19 @@
 #' @seealso \link{rimse} \link{th_est_ml} \link{th_est_eap} \link{sl_link}
 #' \link{hb_link}
 #'
+#'  @importFrom stats dnorm
 #' @export
 
 
-int_mat <- function(distr = dnorm, par1 = 0, par2 = 1,
-                    lb = -4, ub = 4, npts = 10000){
+int_mat <- function(distr = dnorm, args = list(mean = 0, sd = 1),
+                    lb = -4, ub = 4, npts = 10000) {
 
   # take a uniform sequence of points over the given range
   xvals <- seq(lb, ub, length = npts)
 
   # find the height of the density function at each point
-  yvals <- distr(xvals, par1, par2)
+  
+  yvals <- do.call(distr, c(list(x = xvals), args))
 
   # normalize the y values
   yvals <- yvals / sum(yvals)
